Django cradmin
==============
Django custom role based admin UI.

Django cradmin is in BETA. The system is fairly stable, but:

- We do not have getting started guides.
- We should have better tests before release. Some parts have been prototyped
  a lot while we tested out different concepts, and they need a complexity
  review and better tests.

.. image:: https://codeship.com/projects/4e411aa0-40f5-0133-2d9e-2ac35c471c3a/status?branch=master
    :target: https://codeship.com/projects/103536


Docs
====
http://cradmin-legacy.readthedocs.org


License
=======
3-clause BSD license. See the LICENSE file in the same directory as this readme file.
